@@ -2,8 +2,11 @@
  * Programmer(s): Cody J. Balos, Aaron Collier and Radu Serban @ LLNL
  * -----------------------------------------------------------------
  * SUNDIALS Copyright Start
- * Copyright (c) 2002-2025, Lawrence Livermore National Security
+ * Copyright (c) 2025, Lawrence Livermore National Security,
+ * University of Maryland Baltimore County, and the SUNDIALS contributors.
+ * Copyright (c) 2013-2025, Lawrence Livermore National Security
  * and Southern Methodist University.
+ * Copyright (c) 2002-2013, Lawrence Livermore National Security.
  * All rights reserved.
  *
  * See the top-level LICENSE and NOTICE files for details.
@@ -44,12 +47,12 @@
  * -----------------------------------------------------------------*/
 
 
-#define SUNDIALS_VERSION "7.4.0"
+#define SUNDIALS_VERSION "7.5.0"
 #define SUNDIALS_VERSION_MAJOR 7
-#define SUNDIALS_VERSION_MINOR 4
+#define SUNDIALS_VERSION_MINOR 5
 #define SUNDIALS_VERSION_PATCH 0
 #define SUNDIALS_VERSION_LABEL ""
-#define SUNDIALS_GIT_VERSION "v7.4.0"
+#define SUNDIALS_GIT_VERSION "v7.5.0"
 
 
 /* ------------------------------------------------------------------
@@ -112,7 +115,7 @@
 /* Build metadata */
 #define SUN_C_COMPILER "GNU"
 #define SUN_C_COMPILER_VERSION "15.2.1"
-#define SUN_C_COMPILER_FLAGS "-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g -ffile-prefix-map=/build/sundials/src=/usr/src/debug/sundials -flto=auto"
+#define SUN_C_COMPILER_FLAGS "-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection -flto=auto"
 
 #define SUN_CXX_COMPILER ""
 #define SUN_CXX_COMPILER_VERSION ""
@@ -124,8 +127,8 @@
 
 #define SUN_BUILD_TYPE "RelWithDebInfo"
 
-#define SUN_JOB_ID "20250823130931"
-#define SUN_JOB_START_TIME "20250823130931"
+#define SUN_JOB_ID "20250930130236"
+#define SUN_JOB_START_TIME "20250930130236"
 
 #define SUN_TPL_LIST "MPI;OPENMP;KLU;PTHREAD"
 #define SUN_TPL_LIST_SIZE ""
